@@ -11,7 +11,7 @@ __author__ = "Shyue Ping Ong, Anubhav Jain"
 __copyright__ = "Copyright 2012, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __date__ = "Mar 19, 2012"
 
 
