@@ -59,6 +59,23 @@ def select_pseudos(pseudos, structure):
     return PseudoTable(pseudos)
 
 
+class StrategyWithInput(object):
+    # TODO: Find a better way to do this. I will likely need to refactor the Strategy object
+    def __init__(self, abinit_input):
+        self.abinit_input = abinit_input
+                                         
+    @property
+    def pseudos(self):
+        return self.abinit_input.pseudos
+
+    def add_extra_abivars(self, abivars):
+        """Add variables (dict) to extra_abivars."""
+        self.abinit_input.set_variables(**abivars)
+                                         
+    def make_input(self):
+        return str(self.abinit_input)
+
+
 class Strategy(object):
     """
     A Strategy object generates the ABINIT input file used for a particular type of calculation
