@@ -10,7 +10,7 @@ __author__ = "Shyue Ping Ong"
 __copyright__ = "Copyright 2011, The Materials Project"
 __version__ = "1.0"
 __maintainer__ = "Shyue Ping Ong"
-__email__ = "shyue@mit.edu"
+__email__ = "shyuep@gmail.com"
 __status__ = "Production"
 __date__ = "Sep 23, 2011"
 
@@ -211,7 +211,7 @@ class CifWriter:
         for cell_attr in ['a', 'b', 'c']:
             block["_cell_length_" + cell_attr] = str(getattr(latt, cell_attr))
         for cell_attr in ['alpha', 'beta', 'gamma']:
-            block["_cell_angle_" + cell_attr] = str(getattr(latt, cell_attr))
+            block["_cell_angle_" + cell_attr] = float(getattr(latt, cell_attr))
         block["_chemical_name_systematic"] = "Generated by pymatgen"
         block["_symmetry_Int_Tables_number"] = 1
         block["_chemical_formula_structural"] = str(no_oxi_comp
